"use client";
import useFetch from "@/hooks/useFetch";
import { useEffect, useState, useRef } from "react";
import { FaPlus } from "react-icons/fa6";
import VideoItem from "@/ui/(console)/projects/video-item";
import { useRouter } from "next/navigation";
import Loading from "@/components/Loading";
import { useTranslations } from "next-intl";
import { list } from "postcss";

export default function Page() {
    const t = useTranslations("project");
    const router = useRouter();
    const [page, setPage] = useState(1);
    const [videos, setVideos] = useState<any>([]);
    const [hasMore, setHasMore] = useState(true);
    const [loadingMore, setLoadingMore] = useState(false);
    const observerRef = useRef(null); // 用于观察的元素
    const {
        data: videoData,
        loading,
        fetchData: fetchVideoList,
    } = useFetch({
        url: `/api/video-list/?page=${page}&page_size=10`,
        method: "GET",
        cacheTime: 0,
    });

    // 获取视频列表
    useEffect(() => {
        if (page === 1) {
            fetchVideoList().then((res) => {
                setVideos(res.list || []);
                setHasMore(res.page < res.total_pages); // 检查是否还有更多页面
            });
        } else if (!loadingMore) {
            setLoadingMore(true);
            fetchVideoList().then((res) => {
                setVideos((prevVideos) => [...prevVideos, ...(res.list || [])]);
                setHasMore(res.page < res.total_pages);
                setLoadingMore(false);
            });
        }
    }, [page]);

    // 触底加载更多
    useEffect(() => {
        const observer = new IntersectionObserver(
            (entries) => {
                if (entries[0].isIntersecting && hasMore && !loadingMore) {
                    setPage((prevPage) => prevPage + 1);
                }
            },
            { threshold: 1 }
        );

        if (observerRef.current) {
            observer.observe(observerRef.current);
        }

        return () => {
            if (observerRef.current) observer.unobserve(observerRef.current);
        };
    }, [hasMore, loadingMore]);

    // 没有滚动条时继续加载
    useEffect(() => {
        const handleNoScrollBar = () => {
            if (
                document.documentElement.scrollHeight <=
                    document.documentElement.clientHeight &&
                hasMore
            ) {
                setPage((prevPage) => prevPage + 1);
            }
        };

        handleNoScrollBar(); // 初始化时检查

        window.addEventListener("resize", handleNoScrollBar); // 窗口大小变化时检查

        return () => {
            window.removeEventListener("resize", handleNoScrollBar);
        };
    }, [hasMore]);

    return (
        <div className="bg-base-100 flex-[80%] overflow-auto flex flex-col gap-8 p-8">
            <div className="min-h-screen w-full pr-0">
                <main className="w-full">
                    <div className="flex justify-between items-center w-full">
                        <div className="flex flex-col">
                            <div className="text-2xl font-bold">
                                {t("yourVideos")}
                            </div>
                        </div>
                        <button
                            onClick={() => router.push("/create")}
                            className="inline-flex gap-1.5 items-center justify-center whitespace-nowrap z-0 text-sm font-medium ring-offset-background transition-all focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring focus-visible:ring-offset-2 disabled:pointer-events-none disabled:opacity-50 bg-black border border-black relative w-auto text-white px-4 py-2 rounded-md"
                        >
                            <span className="btn-icon">
                                <FaPlus size="1em" />
                            </span>
                            {t("newVideo")}
                        </button>
                    </div>
                    <div className="pt-8 h-full">
                        <div className="grid grid-cols-1 md:grid-cols-3 lg:grid-cols-4 gap-8 w-full">
                            {videos.length > 0 ? (
                                videos.map((item, index) => (
                                    <VideoItem
                                        item={item}
                                        key={index}
                                    ></VideoItem>
                                ))
                            ) : (
                                <></>
                            )}
                        </div>
                        {loadingMore && <Loading />}{" "}
                        {/* 加载更多时显示加载中 */}
                        <div ref={observerRef} style={{ height: 1 }}></div>{" "}
                        {/* 观察触底的元素 */}
                    </div>
                </main>
            </div>
        </div>
    );
}
