import { GetPostList } from "@/apis/auth";
import { getLocale } from "next-intl/server";
import Image from "next/image";
import Link from "next/link";

export default async function ArticleList({ params, searchParams }) {
    const page = parseInt(params.page, 10) || 1; // 获取当前页码
    const locale = await getLocale();
    const limit = 9; // 每页文章数
    const tag = searchParams.tag || ""; // 获取 URL 中的 tag 参数

    interface Article {
        id: number;
        title: string;
        keywords: string;
        image_url: string;
        published_at: string;
    }

    let list: Article[] = [];
    let totalPages = 1;
    let keywords = [];

    try {
        const data = await GetPostList({
            t: new Date().getTime(),
            page,
            limit,
            tag, // 如果有 tag，带上 tag 参数
        });
        if (data.code === 200) {
            list = data.data.articles;
            totalPages = Math.ceil(data.data.count / limit); // 计算总页数
            keywords = data.data[`${locale}_keywords`];
        }
    } catch {}

    return (
        <div className="container mx-auto px-4 py-8">
            {/* 关键词筛选部分 */}
            <div className="mb-6">
                <h3 className="text-xl font-bold text-white mb-4">
                    {" "}
                    {locale === "en" ? "Filtering tags" : "筛选标签"}:
                </h3>
                <div className="flex flex-wrap">
                    {/* 全部标签 */}
                    <Link
                        href={`/article-list/1`}
                        className={`mr-4 mb-2 px-4 py-1 rounded text-sm ${
                            !tag
                                ? "bg-secondary text-white"
                                : "bg-gray-800 text-gray-300 hover:bg-gray-700"
                        }`}
                    >
                        {locale === "en" ? "all" : "全部"}
                    </Link>
                    {keywords.map((keyword, index) => (
                        <Link
                            href={`/article-list/1?tag=${keyword}`}
                            key={index}
                            className={`mr-4 mb-2 px-4 py-1 rounded text-sm ${
                                tag === keyword
                                    ? "bg-secondary text-white"
                                    : "bg-gray-800 text-gray-300 hover:bg-gray-700"
                            }`}
                        >
                            #{keyword}
                        </Link>
                    ))}
                </div>
            </div>

            {/* 文章列表部分 */}
            <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
                {list.map((item, index) => (
                    <div
                        className="bg-[#15171a] rounded-lg overflow-hidden shadow-lg"
                        key={index}
                    >
                        <Link href={`/article/${item.id}`}>
                            <Image
                                src={item["image_url"]}
                                width={960}
                                height={960}
                                alt={item[`${locale}_keywords`].join()}
                                className="w-full h-48 object-cover"
                            />
                        </Link>

                        <div className="p-6">
                            <Link
                                href={`/article/${item.id}`}
                                className="text-white hover:text-secondary hover:underline"
                            >
                                <h2 className="text-xl font-bold  mb-2">
                                    {item[`${locale}_title`]}
                                </h2>
                            </Link>
                            <p className="text-gray-400 text-sm mb-4">
                                {new Date(
                                    item["published_at"]
                                ).toLocaleDateString(locale, {
                                    year: "numeric",
                                    month: "long",
                                    day: "numeric",
                                })}
                            </p>
                            <p className="text-gray-300 mb-6">
                                {item[`${locale}_keywords`].map(
                                    (kitem, kindex) => (
                                        <Link
                                            href={`/article-list/1?tag=${kitem}`}
                                            key={kindex}
                                            className="mr-2 text-sm hover:underline hover:text-secondary"
                                        >
                                            #{kitem}
                                        </Link>
                                    )
                                )}
                            </p>
                            <Link
                                href={`/article/${item.id}`}
                                className="text-secondary hover:underline"
                            >
                                Read More
                            </Link>
                        </div>
                    </div>
                ))}
            </div>

            {/* 分页按钮 */}
            <div className="join mt-8 flex justify-center">
                {Array.from({ length: totalPages }, (_, index) => (
                    <Link
                        href={`/article-list/${index + 1}${
                            tag ? `?tag=${tag}` : ""
                        }`}
                        key={index}
                        className={`join-item btn btn-md ${
                            page === index + 1
                                ? "bg-secondary text-white"
                                : "bg-gray-800 text-gray-300 hover:bg-gray-700"
                        }`}
                    >
                        {index + 1}
                    </Link>
                ))}
            </div>
        </div>
    );
}
