import { useState, useEffect, useRef } from "react";
import { BiUpload } from "react-icons/bi";
import { FaPlay, FaPause } from "react-icons/fa";
import useFetch from "@/hooks/useFetch";
import { useToast } from "@/contexts/ToastContext"; // 假设 ToastContext 在 contexts 文件夹中
import { useTranslations } from "next-intl"; // 导入国际化 hook

interface AudioUploadProps {
    onChange?: (audioUrl: string) => void;
}

const UploadAudio = ({ onChange }: AudioUploadProps) => {
    const t = useTranslations("uploadAudio"); // 使用翻译
    const [file, setFile] = useState<File | null>(null);
    const [audioUrl, setAudioUrl] = useState<string | null>(null);
    const [isPlaying, setIsPlaying] = useState(false);
    const [currentTime, setCurrentTime] = useState(0);
    const [duration, setDuration] = useState(0);
    const [uploading, setUploading] = useState(false);

    const audioRef = useRef<HTMLAudioElement | null>(null);
    const { fetchData } = useFetch({
        url: "/api/upload-audio/",
        method: "POST",
    });
    const { addToast } = useToast();

    const handleFileChange = async (e: React.ChangeEvent<HTMLInputElement>) => {
        const selectedFile = e.target.files?.[0];
        if (selectedFile) {
            setFile(selectedFile);
            setUploading(true);

            const formData = new FormData();
            formData.append("audio", selectedFile);

            fetchData(formData)
                .then((res) => {
                    console.log("upload audio：", res);
                    const audioUrl = res.audio_url; // 假设返回数据中有 audio_url
                    setAudioUrl(audioUrl);
                    addToast(t("uploadSuccess"), "success"); // 使用翻译
                    if (onChange) {
                        onChange(audioUrl);
                    }
                })
                .finally(() => {
                    setUploading(false);
                });
        }
    };

    const togglePlayPause = () => {
        if (audioRef.current) {
            if (isPlaying) {
                audioRef.current.pause();
            } else {
                audioRef.current.play();
            }
            setIsPlaying(!isPlaying);
        }
    };

    const handleTimeUpdate = () => {
        if (audioRef.current) {
            setCurrentTime(audioRef.current.currentTime);
        }
    };

    const handleLoadedMetadata = () => {
        if (audioRef.current) {
            setDuration(audioRef.current.duration);
        }
    };

    const handleEnded = () => {
        setIsPlaying(false);
        setCurrentTime(0); // 重置播放时间
    };

    useEffect(() => {
        if (audioRef.current) {
            audioRef.current.addEventListener("timeupdate", handleTimeUpdate);
            audioRef.current.addEventListener(
                "loadedmetadata",
                handleLoadedMetadata
            );
            audioRef.current.addEventListener("ended", handleEnded);
        }
        return () => {
            if (audioRef.current) {
                audioRef.current.removeEventListener(
                    "timeupdate",
                    handleTimeUpdate
                );
                audioRef.current.removeEventListener(
                    "loadedmetadata",
                    handleLoadedMetadata
                );
                audioRef.current.removeEventListener("ended", handleEnded);
            }
        };
    }, [audioUrl]);

    const formatTime = (time: number) => {
        const minutes = Math.floor(time / 60);
        const seconds = Math.floor(time % 60);
        return `${minutes}:${seconds < 10 ? "0" : ""}${seconds}`;
    };

    const calculateGradient = () => {
        const percentage = (currentTime / duration) * 100 || 0;
        return `linear-gradient(to right, rgba(74, 222, 128, 0.2) ${percentage}%, rgba(74, 222, 128, 0.05) ${percentage}%)`;
    };

    return (
        <div>
            <div
                role="presentation"
                tabIndex={0}
                className="relative px-4 py-6 bg-ivory w-full min-w-[100px] border border-dashed border-info border-opacity-30 rounded-lg flex flex-col items-center justify-center gap-1 cursor-pointer"
                onClick={() =>
                    document.getElementById("audio-upload-input")?.click()
                }
            >
                <input
                    id="audio-upload-input"
                    accept="audio/*"
                    type="file"
                    tabIndex={-1}
                    style={{ display: "none" }}
                    onChange={handleFileChange}
                />
                {uploading ? (
                    <span className="loading loading-dots loading-lg text-secondary">
                        {t("uploading")}
                    </span>
                ) : (
                    <>
                        <BiUpload className="w-[35px] h-[35px] text-secondary" />
                        <div className="font-normal text-xs text-info text-center">
                            {t("dropOrClick")}
                        </div>
                    </>
                )}
            </div>
            {audioUrl && (
                <div className="relative z-0 mt-4">
                    <div
                        className="p-2 cursor-pointer hover:outline hover:outline-base-100 outline-offset-2 border border-base-200 rounded-lg flex flex-col gap-3"
                        style={{
                            background: isPlaying
                                ? calculateGradient()
                                : "rgb(255, 255, 255)",
                            transition: "background 0.1s linear",
                        }}
                    >
                        <audio
                            ref={audioRef}
                            src={audioUrl}
                            className="audio-preview hidden"
                            preload="metadata"
                        ></audio>
                        <div className="flex gap-2 justify-between items-center">
                            <div className="flex flex-[70%] overflow-hidden gap-2 items-center">
                                <div
                                    className="ml-2 mr-1"
                                    onClick={togglePlayPause}
                                >
                                    {isPlaying ? (
                                        <FaPause
                                            className="cursor-pointer flex-shrink-0 text-info"
                                            size={18}
                                        />
                                    ) : (
                                        <FaPlay
                                            className="cursor-pointer flex-shrink-0 text-info"
                                            size={18}
                                        />
                                    )}
                                </div>
                                <div className="overflow-hidden">
                                    <div className="flex whitespace-nowrap text-ellipsis truncate overflow-hidden text-xs font-bold">
                                        {file?.name}
                                    </div>
                                    <div className="overflow-hidden text-info text-[10px] truncate">
                                        {t("audioFile")}
                                    </div>
                                </div>
                            </div>
                            <div className="flex justify-end gap-1 flex-[30%]">
                                <small>{formatTime(currentTime)}</small>
                                <small> / </small>
                                <small>{formatTime(duration)}</small>
                            </div>
                        </div>
                    </div>
                </div>
            )}
        </div>
    );
};

export default UploadAudio;
