import { useToast } from "@/contexts/ToastContext";
import useFetch from "@/hooks/useFetch";
import { useState } from "react";
import { TfiUser } from "react-icons/tfi";
import { useTranslations } from "next-intl";
import Image from "next/image";

interface ImageUploadProps {
    onChange?: (imageUrl: string) => void;
}

const ImageUpload = ({ onChange }: ImageUploadProps) => {
    const t = useTranslations("imageUpload"); // 使用翻译
    const [previewUrl, setPreviewUrl] = useState<string | null>(null);
    const [uploading, setUploading] = useState(false);
    const { addToast } = useToast();

    const { fetchData } = useFetch({
        url: "/api/upload-avatar/",
        method: "POST",
    });

    const handleImageChange = (e: React.ChangeEvent<HTMLInputElement>) => {
        const file = e.target.files?.[0];
        if (file) {
            setUploading(true);
            const formData = new FormData();
            formData.append("avatar", file);
            fetchData(formData)
                .then((res) => {
                    const imageUrl = URL.createObjectURL(file);
                    setPreviewUrl(imageUrl);
                    addToast(t("uploadSuccess"), "success"); // 使用翻译
                    if (onChange) {
                        onChange(res.avatar_url);
                    }
                })
                .finally(() => {
                    setUploading(false);
                });
        }
    };

    return (
        <div className="flex justify-center items-center min-h-64 w-64 m-4 border-2 border-dashed border-gray-400 rounded-lg cursor-pointer hover:border-secondary relative">
            <input
                type="file"
                accept="image/*"
                onChange={handleImageChange}
                className="absolute opacity-0 w-full h-full cursor-pointer"
            />
            <div className="flex flex-col items-center justify-center text-gray-500">
                {uploading ? (
                    <span className="loading loading-dots loading-lg">
                        {t("loading")}
                    </span>
                ) : previewUrl ? (
                    <Image
                        src={previewUrl}
                        alt="Preview"
                        width={100}
                        height={100}
                        className="object-contain w-full h-full rounded-lg"
                    />
                ) : (
                    <>
                        <TfiUser size={48} />
                        <p>{t("uploadImage")}</p> {/* 使用翻译 */}
                    </>
                )}
            </div>
        </div>
    );
};

export default ImageUpload;
