// components/DialogProvider.tsx
"use client";
import React, { createContext, useContext, useState, ReactNode } from "react";
import { motion, AnimatePresence } from "framer-motion";
import { useTranslations } from "next-intl";

interface DialogContextType {
    showDialog: (
        message: string,
        onConfirm: () => void,
        onCancel?: () => void
    ) => void;
}
interface Dialog {
    id: number;
    message: string;
    onConfirm: () => void;
    onCancel?: () => void;
}

const DialogContext = createContext<DialogContextType | undefined>(undefined);

export const DialogProvider: React.FC<{ children: ReactNode }> = ({
    children,
}) => {
    const [dialogs, setDialogs] = useState<Dialog[]>([]);
    const [nextId, setNextId] = useState(0);
    const t = useTranslations("dialog");
    const showDialog = (
        message: string,
        onConfirm: () => void,
        onCancel?: () => void
    ) => {
        setDialogs((prevDialogs) => [
            ...prevDialogs,
            { id: nextId, message, onConfirm, onCancel },
        ]);
        setNextId(nextId + 1);
    };

    const removeDialog = (id: number) => {
        setDialogs((prevDialogs) =>
            prevDialogs.filter((dialog) => dialog.id !== id)
        );
    };

    return (
        <DialogContext.Provider value={{ showDialog }}>
            {children}
            {/* Dialog container */}
            <AnimatePresence>
                {dialogs.map((dialog) => (
                    <motion.div
                        key={dialog.id}
                        initial={{ opacity: 0 }}
                        animate={{ opacity: 1 }}
                        exit={{ opacity: 0 }}
                        transition={{ duration: 0.3 }}
                        className="fixed inset-0 flex items-center justify-center z-[9999] bg-black bg-opacity-50"
                    >
                        <motion.div
                            initial={{ scale: 0.5, opacity: 0 }}
                            animate={{ scale: 1, opacity: 1 }}
                            exit={{ scale: 0.5, opacity: 0 }}
                            transition={{ duration: 0.2, ease: "easeOut" }}
                            className="bg-white rounded-lg shadow-lg p-6 w-[300px] text-center"
                        >
                            <div className="mb-4 text-lg">{dialog.message}</div>
                            <div className="flex justify-end gap-3 mt-4">
                                <button
                                    className="btn btn-sm"
                                    onClick={() => {
                                        dialog.onCancel?.();
                                        removeDialog(dialog.id);
                                    }}
                                >
                                    {t("Cancel")}
                                </button>
                                <button
                                    className="btn btn-secondary btn-sm"
                                    onClick={() => {
                                        dialog.onConfirm();
                                        removeDialog(dialog.id);
                                    }}
                                >
                                    {t("Confirmation")}
                                </button>
                            </div>
                        </motion.div>
                    </motion.div>
                ))}
            </AnimatePresence>
        </DialogContext.Provider>
    );
};

// 自定义 hook 来使用 DialogContext
export const useDialog = () => {
    const context = useContext(DialogContext);
    if (context === undefined) {
        throw new Error("useDialog must be used within a DialogProvider");
    }
    return context;
};
