// components/ToastProvider.tsx
"use client";
import React, { createContext, useContext, useState, ReactNode } from "react";
import { motion, AnimatePresence } from "framer-motion";
import { MdError } from "react-icons/md";
import { MdCheckCircle } from "react-icons/md";

interface ToastContextType {
    addToast: (message: string, type?: ToastType) => void;
    addToastError: (message: string) => void;
    addToastSuccess: (message: string) => void;
}
type ToastType = "default" | "error" | "success";
interface Toast {
    id: number;
    message: string;
    type: ToastType;
}

const ToastContext = createContext<ToastContextType | undefined>(undefined);

export const ToastProvider: React.FC<{ children: ReactNode }> = ({
    children,
}) => {
    const [toasts, setToasts] = useState<Toast[]>([]);
    const [nextId, setNextId] = useState(0);

    const addToast = (message: string, type: ToastType = "default") => {
        setToasts((prevToasts) => [
            ...prevToasts,
            { id: nextId, message, type },
        ]);
        setNextId(nextId + 1);
    };
    const addToastError = (message: string) => {
        addToast(message, "error");
    };

    const addToastSuccess = (message: string) => {
        addToast(message, "success");
    };
    const removeToast = (id: number) => {
        setToasts((prevToasts) =>
            prevToasts.filter((toast) => toast.id !== id)
        );
    };

    return (
        <ToastContext.Provider
            value={{ addToast, addToastError, addToastSuccess }}
        >
            {children}
            <div
                className=" z-[9999] left-0 right-0 top-0 flex justify-center pointer-events-none"
                style={{ position: "fixed", inset: "16px" }}
            >
                <AnimatePresence>
                    {toasts.map((toast, index) => (
                        <motion.div
                            key={toast.id}
                            initial={{ opacity: 0, translateY: 20, scale: 0.5 }}
                            animate={{
                                opacity: 1,
                                translateY: 60 * index + 20,
                                scale: 1,
                            }}
                            exit={{ opacity: 0, translateY: 20, scale: 0.5 }}
                            transition={{ duration: 0.2, ease: "easeOut" }}
                            className="absolute rounded-lg shadow-lg bg-white py-2 px-6"
                            onAnimationComplete={() =>
                                setTimeout(() => removeToast(toast.id), 3000)
                            }
                        >
                            <div className="flex items-center">
                                {toast.type === "error" && (
                                    <MdError
                                        size={20}
                                        className="text-red-500 mr-2"
                                    />
                                )}
                                {toast.type === "success" && (
                                    <MdCheckCircle
                                        size={20}
                                        className="text-green-500 mr-2"
                                    />
                                )}
                                {toast.message}
                            </div>
                        </motion.div>
                    ))}
                </AnimatePresence>
            </div>
        </ToastContext.Provider>
    );
};

export const useToast = () => {
    const context = useContext(ToastContext);
    if (context === undefined) {
        throw new Error("useToast must be used within a ToastProvider");
    }
    return context;
};
