import React, { useEffect, useState } from "react";
import useFetch from "@/hooks/useFetch";
import classNames from "classnames";
import * as Collapsible from "@radix-ui/react-collapsible";
import * as Tabs from "@radix-ui/react-tabs";
import { IoChevronDown, IoPlay, IoPause } from "react-icons/io5";
import { useTranslations, useLocale } from "next-intl";
import { GetSpeakersData } from "@/apis/auth";
// 定义接口
export interface VideoData {
    language: string;
    videoSelect: string;
    style: string;
}

export default function VideoSelect({
    onChange,
}: {
    onChange: (data: VideoData) => void;
}) {
    const t = useTranslations("video");

    const locale = useLocale();
    // const [speakersData, setSpeakersData] = useState<any>([]);
    const {
        data: speakersData,
        loading: speakersLoading,
        error: speakersError,
        fetchData: fetchSpeakers,
    } = useFetch({
        url: "/api/get_speakers/",
        method: "GET",
        cacheTime: 0,
    });

    const [videoFormState, setVideoFormState] = useState({
        language: "zh-CN", // 国家语种
        videoSelect: "", // 讲话人
        style: "", // 讲话风格
    });

    const [currentVideo, setCurrentVideo] = useState<any>({}); // 当前讲话人对象
    const [isPlaying, setIsPlaying] = useState<string | null>(null); // 当前播放的音频标识
    const [audio, setAudio] = useState<HTMLAudioElement | null>(null); // 音频对象

    // GetSpeakersData().then((res) => {
    //     console.log("res", res);
    //     setSpeakersData(res.data);
    //     videoChange(res.data[0].讲话人[0]);
    // });
    useEffect(() => {
        fetchSpeakers()
            .then((res) => {
                console.log("Fetched speakers data:", res);
                videoChange(res[0].讲话人[0]);
            })
            .catch((err) => {
                console.error("Failed to fetch speakers data:", err);
            });
    }, []);

    const languageChange = (val: string) => {
        const selectedLanguage = getLanguageSpeaker(val);
        const video = selectedLanguage.讲话人[0];
        const newState = {
            language: val,
            videoSelect: video.讲话人英文参数,
            style: video.风格列表.length > 0 ? video.风格列表[0].英文参数 : "",
        };
        setVideoFormState(newState);
        setCurrentVideo(video); // 设置当前讲话人
    };

    const getLanguageSpeaker = (language: string) => {
        return speakersData.find((item) => item.语言参数 === language);
    };

    const videoChange = (item: any) => {
        const newState = {
            ...videoFormState,
            videoSelect: item.讲话人英文参数,
            style: item.风格列表.length > 0 ? item.风格列表[0].英文参数 : "",
        };
        setVideoFormState(newState);
        setCurrentVideo(item); // 设置当前讲话人
    };

    useEffect(() => {
        console.log("videoFormState", videoFormState);
        onChange(videoFormState);
    }, [videoFormState, onChange]);

    const handleToggle = (index) => {
        setOpenStates((prevState) => ({
            ...prevState,
            [index]: !prevState[index], // 切换对应 index 的 open 状态
        }));
    };

    const [openStates, setOpenStates] = useState({}); // 为每个 Collapsible 创建独立的 open 状态

    const handlePlay = (audioUrl: string) => {
        // 先停止当前播放的音频
        if (audio) {
            audio.pause();
            audio.currentTime = 0; // 将音频重置到开头
        }

        // 播放新音频
        const newAudio = new Audio(audioUrl);
        setAudio(newAudio);
        setIsPlaying(audioUrl);
        newAudio.play();

        newAudio.onended = () => {
            setIsPlaying(null);
        };
    };

    return (
        <Tabs.Root
            className=""
            defaultValue="zh-CN"
            value={videoFormState.language}
            onValueChange={languageChange}
        >
            <div className="mb-2">{t("language")}</div>
            <Tabs.List className="w-full flex flex-wrap gap-3 mb-4">
                {speakersData &&
                    speakersData.map((item, index) => (
                        <Tabs.Trigger
                            key={index}
                            value={item.语言参数}
                            className={classNames(
                                "relative rounded-md border border-base-200 bg-white px-3 flex gap-2 items-center justify-center cursor-pointer",
                                {
                                    "outline-2 outline-offset-1 outline outline-secondary/80":
                                        videoFormState.language ===
                                        item.语言参数,
                                }
                            )}
                        >
                            {t(item.语言参数)}
                        </Tabs.Trigger>
                    ))}
            </Tabs.List>
            {speakersData &&
                speakersData.map((item, index) => (
                    <Tabs.Content key={index} value={item.语言参数}>
                        <div className="">
                            <div className="mb-2">{t("speaker")}</div>
                            <div className="grid grid-cols-2 gap-2 flex-wrap w-full">
                                {item.讲话人
                                    .slice(0, 6)
                                    .map((speakItem, speakIndex) => (
                                        <div
                                            key={speakIndex}
                                            className="w-full relative group"
                                            onClick={() =>
                                                videoChange(speakItem)
                                            }
                                        >
                                            <div className="relative z-0">
                                                <div
                                                    className={classNames(
                                                        "p-2 cursor-pointer border border-base-200 rounded-lg flex flex-col gap-3",
                                                        {
                                                            "outline outline-2 outline-secondary outline-offset-2 bg-secondary bg-opacity-[0.02]":
                                                                videoFormState.videoSelect ===
                                                                speakItem.讲话人英文参数,
                                                        }
                                                    )}
                                                >
                                                    <div className="flex gap-2 justify-between items-center">
                                                        {speakItem.讲话人中文名}
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    ))}
                            </div>
                            <Collapsible.Root
                                className="CollapsibleRoot"
                                open={openStates[index] || false}
                                onOpenChange={() => handleToggle(index)}
                            >
                                <div className="border-b border-none">
                                    {item.讲话人.length > 6 && (
                                        <Collapsible.Trigger
                                            asChild
                                            className="my-2"
                                        >
                                            <button className="cursor-pointer flex flex-1 text-xs items-center font-medium transition-all hover:bg-base-100/50 rounded-lg p-2 gap-1.5 [&[data-state=open]>svg]:rotate-180 justify-start">
                                                <label className="cursor-pointer">
                                                    {t("findMoreVoices")}
                                                </label>
                                                <IoChevronDown />
                                            </button>
                                        </Collapsible.Trigger>
                                    )}
                                    {item.讲话人.length > 6 && (
                                        <Collapsible.Content className="transition-all data-[state=closed]:animate-accordion-up data-[state=open]:animate-accordion-down overflow-visible">
                                            <div className="grid grid-cols-2 gap-2 flex-wrap w-full">
                                                {item.讲话人
                                                    .slice(6)
                                                    .map(
                                                        (
                                                            speakItem,
                                                            speakIndex
                                                        ) => (
                                                            <div
                                                                key={
                                                                    speakIndex +
                                                                    6
                                                                }
                                                                className="w-full relative group"
                                                                onClick={() =>
                                                                    videoChange(
                                                                        speakItem
                                                                    )
                                                                }
                                                            >
                                                                <div className="relative z-0">
                                                                    <div
                                                                        className={classNames(
                                                                            "p-2 cursor-pointer  border border-base-200 rounded-lg flex flex-col gap-3",
                                                                            {
                                                                                "outline outline-2 outline-secondary outline-offset-2 bg-secondary bg-opacity-[0.02]":
                                                                                    videoFormState.videoSelect ===
                                                                                    speakItem.讲话人英文参数,
                                                                            }
                                                                        )}
                                                                    >
                                                                        <div className="flex gap-2 justify-between items-center">
                                                                            <div className="">
                                                                                {
                                                                                    speakItem.讲话人中文名
                                                                                }
                                                                            </div>
                                                                        </div>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        )
                                                    )}
                                            </div>
                                        </Collapsible.Content>
                                    )}
                                </div>
                            </Collapsible.Root>
                        </div>
                        <div className="pt-2">
                            <div className="mb-2"> {t("speakingStyle")}</div>
                            <div className="h-full flex flex-col">
                                <div className="flex flex-wrap gap-2">
                                    {JSON.stringify(currentVideo) !== "{}" &&
                                        currentVideo.风格列表.map(
                                            (styleItem, styleIndex) => {
                                                const audioUrl = `/audio/${videoFormState.videoSelect}_${styleItem.英文参数}.mp3`; // 假设音频文件存放在 public/audio 目录中
                                                return (
                                                    <button
                                                        key={styleIndex}
                                                        className={classNames(
                                                            "px-2 py-1 border border-base-200 rounded-md text-xs cursor-pointer hover:bg-secondary/80 hover:text-white flex items-center gap-2",
                                                            {
                                                                "bg-secondary text-white":
                                                                    videoFormState.style ===
                                                                    styleItem.英文参数,
                                                            }
                                                        )}
                                                        onClick={() => {
                                                            setVideoFormState(
                                                                (
                                                                    prevState
                                                                ) => ({
                                                                    ...prevState,
                                                                    style: styleItem.英文参数,
                                                                })
                                                            );
                                                            handlePlay(
                                                                audioUrl
                                                            ); // 点击播放音频
                                                        }}
                                                    >
                                                        {/* {isPlaying ===
                                                        audioUrl ? (
                                                            <IoPause className="animate-spin" />
                                                        ) : (
                                                
                                                        )} */}
                                                        <div className="flex items-center">
                                                            <IoPlay
                                                                className={
                                                                    videoFormState.style ===
                                                                    styleItem.英文参数
                                                                        ? "text-white mr-1"
                                                                        : " mr-1"
                                                                }
                                                            />
                                                            <div>
                                                                {locale === "zh"
                                                                    ? styleItem.中文参数
                                                                    : styleItem.英文参数}
                                                            </div>
                                                        </div>
                                                    </button>
                                                );
                                            }
                                        )}
                                </div>
                            </div>
                        </div>
                    </Tabs.Content>
                ))}
        </Tabs.Root>
    );
}
