import Link from "next/link";
import { IoEllipsisHorizontal } from "react-icons/io5";
import { useTranslations } from "next-intl";
import useFetch from "@/hooks/useFetch";
import { useEffect } from "react";
import { useToast } from "@/contexts/ToastContext";

export default function VideoItem({ item }) {
    const t = useTranslations("videoItem"); // 使用翻译
    const { addToast } = useToast();
    const {
        fetchData: extendVideo,
        loading: extendVideoLoading,
        data: extendVideoData,
    } = useFetch({
        url: "/api/extend-video/",
        method: "POST",
    });

    const getStatusBadge = (status) => {
        switch (status) {
            case "completed":
                return t("completed");
            case "failed":
                return t("failed");
            case "Pending":
            case "pending":
                return t("pending");
            case "in_progress":
                return t("inProgress");
            default:
                return status;
        }
    };

    const handleExtendVideo = async () => {
        if (extendVideoLoading) return;
        try {
            await extendVideo({ task_id: item.pid, motion_score: null }); // 假设你要传递video的ID
            addToast(t("extendSuccess"), "success");
            window.location.reload(); // 请求成功后刷新页面
        } catch (error) {
            console.error("Failed to extend video", error);
        }
    };

    return (
        <>
            <div className="group flex flex-col gap-4 items-stretch bg-base-100 rounded-lg cursor-pointer bg-opacity-0 hover:bg-opacity-100 transition-all">
                <div className="relative w-full overflow-hidden bg-base-200 p-4 aspect-video rounded-xl flex items-center justify-center">
                    <div className="bg-white w-full h-full rounded-xl shadow-lg mx-3 flex flex-col items-center justify-center overflow-hidden">
                        <video
                            src={item.video_url}
                            controls
                            className="w-full h-auto"
                        ></video>
                    </div>
                </div>
                <div className="flex w-full justify-between items-start">
                    <div className="w-full flex flex-col justify-center gap-0.5">
                        <div className="w-full flex justify-between">
                            <div className="flex items-center font-medium overflow-ellipsis whitespace-nowrap truncate">
                                <div
                                    className={`badge text-white mr-2 ${
                                        item.status === "completed"
                                            ? "bg-secondary"
                                            : item.status === "failed"
                                            ? "bg-red-500"
                                            : item.status === "Pending" ||
                                              item.status === "pending" ||
                                              item.status === "in_progress"
                                            ? "bg-yellow-500"
                                            : ""
                                    }`}
                                >
                                    {getStatusBadge(item.status)}{" "}
                                    {/* 状态翻译 */}
                                </div>

                                <div className="">{item.text}</div>
                            </div>
                            <div className="max-w-8 w-full ml-4">
                                <div className="text-black dropdown dropdown-end">
                                    <label
                                        tabIndex={0}
                                        className="cursor-pointer"
                                    >
                                        <div className="p-[4px] rounded-[6px] bg-base-200 transition-all opacity-[0.4] bg-opacity-0 group-hover:hover:bg-opacity-[.8] group-hover:hover:opacity-[0.8]">
                                            <IoEllipsisHorizontal size={18} />
                                        </div>
                                    </label>
                                    <div
                                        tabIndex={0}
                                        className="mt-2 !opacity-1 min-w-[150px] box-shadow-tf card compact dropdown-content bg-white rounded-xl z-[1000]"
                                    >
                                        <ul className="px-2 py-1.5 flex flex-col gap-1 text-sm">
                                            {item.audio_url ? (
                                                <Link
                                                    href={item.audio_url}
                                                    className="py-[5px] h-8 flex whitespace-nowrap items-center gap-2 text-neutral p-2 hover:bg-base-100 rounded-md"
                                                >
                                                    <div className="flex gap-2 items-center cursor-pointer w-full pr-4 transition-opacity opacity-70 hover:opacity-95">
                                                        {t("downloadingAudio")}{" "}
                                                        {/* 翻译音频下载 */}
                                                    </div>
                                                </Link>
                                            ) : (
                                                <></>
                                            )}
                                            {item.video_url ? (
                                                <Link
                                                    href={item.video_url}
                                                    className="py-[5px] h-8 flex whitespace-nowrap items-center gap-2 text-neutral p-2 hover:bg-base-100 rounded-md"
                                                >
                                                    <div className="flex gap-2 items-center cursor-pointer w-full pr-4 transition-opacity opacity-70 hover:opacity-95">
                                                        {t("downloadingVideos")}{" "}
                                                        {/* 翻译视频下载 */}
                                                    </div>
                                                </Link>
                                            ) : (
                                                <></>
                                            )}
                                            {item.status === "completed" && (
                                                <li
                                                    onClick={handleExtendVideo}
                                                    className="py-[5px] h-8 flex whitespace-nowrap items-center gap-2 text-neutral p-2 hover:bg-base-100 rounded-md cursor-pointer"
                                                >
                                                    <div className="flex gap-2 items-center w-full pr-4 transition-opacity opacity-70 hover:opacity-95">
                                                        {extendVideoLoading ? (
                                                            <span className="loading loading-spinner loading-sm text-secondary"></span>
                                                        ) : (
                                                            t("extendVideo")
                                                        )}
                                                        {/* 翻译扩展视频 */}
                                                    </div>
                                                </li>
                                            )}
                                        </ul>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </>
    );
}
